gc: The Boehm-Demers-Weiser conservative garbage collector
==========================================================

Description
-----------

The Boehm-Demers-Weiser conservative garbage collector.


License
-------

-  MIT-style (https://github.com/ivmai/bdwgc/blob/master/LICENSE)


Upstream Contact
----------------

-  Ivan Maidanski

Webpage:
-  https://github.com/ivmai/bdwgc/
-  https://www.hboehm.info/gc/


Special Update/Build Instructions
---------------------------------

None.
